@@ -1,6 +1,7 @@
 from abc import ABCMeta, abstractmethod
 from senkalib.caaj_journal import CaajJournal
 from senkalib.chain.transaction import Transaction
+from senkalib.token_original_id_table import TokenOriginalIdTable
 from typing import List
 
 class CaajPlugin(metaclass=ABCMeta):
@@ -11,5 +12,5 @@ class CaajPlugin(metaclass=ABCMeta):
     pass
 
   @abstractmethod
-  def get_caajs(cls, address:str, transaction:Transaction, token_original_ids:List) -> List[CaajJournal]:
+  def get_caajs(cls, address:str, transaction:Transaction, token_original_id_table:TokenOriginalIdTable) -> List[CaajJournal]:
     pass
\ No newline at end of file
